@@ -1,6 +1,6 @@
 /*!
 
-# Plotters - Rust Drawing Library for Visualization  🦀📈🚀
+# Plotters - A Rust drawing library focus on data plotting for both WASM and native applications  🦀📈🚀
 
 <a href="https://crates.io/crates/plotters">
     <img style="display: inline!important" src="https://img.shields.io/crates/v/plotters.svg"></img>
@@ -15,8 +15,12 @@
     <img style="display: inline! important" src="https://travis-ci.org/38/plotters.svg?branch=master"></img>
 </a>
 
+<a href="https://codecov.io/gh/38/plotters">
+  <img src="https://codecov.io/gh/38/plotters/branch/master/graph/badge.svg" />
+</a>
+
 Plotters is drawing library designed for rendering figures, plots, and charts, in pure rust. Plotters supports various types of backends,
-including bitmap, vector graph, piston window and WebAssembly.
+including bitmap, vector graph, piston window, GTK/Cairo and WebAssembly.
 
 - To try Plotters with inverative Jupyter notebook, or view [here](https://plotters-rs.github.io/plotters-doc-data/evcxr-jupyter-integration.html) for the static HTML version.
 - To view the WASM example, go to this [link](https://plumberserver.com/plotters-wasm-demo/index.html)
@@ -219,7 +223,7 @@ including bitmap, vector graph, piston window and WebAssembly.
 To use Plotters, you can simply add Plotters into your `Cargo.toml`
 ```toml
 [dependencies]
-plotters = "^0.2.7"
+plotters = "^0.2.8"
 ```
 
 And the following code draws a quadratic function. `src/main.rs`,
@@ -638,8 +642,8 @@ pub mod prelude {
     pub use crate::drawing::*;
     pub use crate::series::{AreaSeries, Histogram, LineSeries, PointSeries};
     pub use crate::style::{
-        Color, FontDesc, FontTransform, HSLColor, IntoFont, Palette, Palette100, Palette99,
-        Palette9999, PaletteColor, RGBColor, ShapeStyle, SimpleColor, TextStyle,
+        AsRelative, Color, FontDesc, FontTransform, HSLColor, IntoFont, Palette, Palette100,
+        Palette99, Palette9999, PaletteColor, RGBColor, ShapeStyle, SimpleColor, TextStyle,
     };
     pub use crate::style::{BLACK, BLUE, CYAN, GREEN, MAGENTA, RED, TRANSPARENT, WHITE, YELLOW};
 
